(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     98496,       2619]
NotebookOptionsPosition[     95414,       2563]
NotebookOutlinePosition[     95974,       2584]
CellTagsIndexPosition[     95931,       2581]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 20 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}, {
   3.890973965108789*^9, 3.8909739653874283`*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"8b28fb0a-428d-4d6f-b9e7-aec283f9b152"],

Cell["Chapter 6, Section 6.10.2", "Section",ExpressionUUID->"ea7d8ce5-727e-496a-b412-fed6b975d708"],

Cell[TextData[{
 "Here we are going to derive an explicit expression for one resonant term \
associated with the motion of Pallas close to the 18:7 resonance with \
Jupiter.\n\nWe start by loading the ",
 StyleBox["DisturbingFunction", "Input"],
 " package.  In this example it is assumed that the file ",
 StyleBox["DisturbingFunction.m",
  FontWeight->"Bold"],
 " is located in the current directory/folder."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"dea4810e-f6e5-4d40-b627-e58c62d9890e"],

Cell["SetDirectory[\"/Users/carl/New_Book/New_Chapter_06\"];", "Input",
 CellChangeTimes->{3.86635954471481*^9},
 CellLabel->"In[1]:=",ExpressionUUID->"ea16910c-c7c9-4eb7-af60-bd4f15c71426"],

Cell["<<DisturbingFunction.m;", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[2]:=",ExpressionUUID->"47c21d89-83d6-422f-aab9-3951b6f27b83"],

Cell[TextData[{
 "Show how the function ",
 StyleBox["ValidArguments", "Input"],
 " is used."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"8ffc35f7-1f11-4269-9e2f-d2d134caf1e4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "ValidArguments"}]], "Input",
 CellLabel->"In[3]:=",ExpressionUUID->"20831f1e-fa37-4bdf-9d54-4e9f0284c6d2"],

Cell[BoxData[
 InterpretationBox[
  StyleBox[
   FrameBox[
    DynamicModuleBox[{System`InformationDump`open$$ = False, 
     System`InformationDump`mouseOver$$ = False}, 
     PaneSelectorBox[{True->
      TagBox[GridBox[{
         {
          ItemBox[
           PaneBox[
            StyleBox["\<\" Symbol\"\>", "InformationTitleText",
             StripOnInput->False,
             BaseStyle -> None],
            FrameMargins->{{4, 0}, {-1, 1}}],
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False], 
          ItemBox["\<\"\"\>",
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False]},
         {
          ItemBox[
           PaneBox[
            
            StyleBox["\<\"ValidArguments[c1,c2,pw] produces an ordered list \
of valid arguments of the expansion of the disturbing function up to and \
including degree 'pw' which start with \\!\\(\\*SubscriptBox[\\(c\\), \
\\(1\\)]\\)\[Lambda]'+\\!\\(\\*SubscriptBox[\\(c\\), \\(2\\)]\\)\[Lambda].  \
The components of each argument, {\\!\\(\\*SubscriptBox[\\(c\\), \\(1\\)]\\),\
\\!\\(\\*SubscriptBox[\\(c\\), \\(2\\)]\\),\\!\\(\\*SubscriptBox[\\(c\\), \
\\(3\\)]\\),\\!\\(\\*SubscriptBox[\\(c\\), \\(4\\)]\\),\\!\\(\\*SubscriptBox[\
\\(c\\), \\(5\\)]\\),\\!\\(\\*SubscriptBox[\\(c\\), \\(6\\)]\\)}, represent \
the argument \\!\\(\\*SubscriptBox[\\(c\\), \
\\(1\\)]\\)\[Lambda]'+\\!\\(\\*SubscriptBox[\\(c\\), \\(2\\)]\\)\[Lambda]+\\!\
\\(\\*SubscriptBox[\\(c\\), \\(3\\)]\\)\[CurlyPi]'+\\!\\(\\*SubscriptBox[\\(c\
\\), \\(4\\)]\\)\[CurlyPi]+\\!\\(\\*SubscriptBox[\\(c\\), \\(5\\)]\\)\
\[CapitalOmega]'+\\!\\(\\*SubscriptBox[\\(c\\), \\(6\\)]\\)\[CapitalOmega].  \
c1 and c2 are integers of the form, e.g. j and i-j, where i, the order of the \
resonance, is an integer.\"\>", "InformationUsageText",
             StripOnInput->False,
             LineSpacing->{1.5, 1.5, 3.}],
            FrameMargins->{{10, 10}, {8, 10}}],
           BaseStyle->"InformationUsageSubtitleBackground",
           StripOnInput->False], 
          ItemBox["\<\"\"\>",
           BaseStyle->"InformationUsageSubtitleBackground",
           StripOnInput->False]},
         {
          PaneBox[
           TagBox[GridBox[{
              {
               StyleBox[
                TagBox[
                 TooltipBox[
                  StyleBox["\<\" Definitions\"\>", "InformationRowLabel",
                   StripOnInput->False],
                  "\"Definitions\"",
                  TooltipStyle->"TextStyling"],
                 Annotation[#, "Definitions", "Tooltip"]& ], "DialogStyle",
                StripOnInput->False]},
              {
               TemplateBox[{"\"\[ThinSpace]\"", 
                 GridBox[{{
                    RowBox[{
                    RowBox[{"ValidArguments", "[", 
                    
                    RowBox[{
                    "DisturbingFunction`Private`c1_", ",", 
                    "DisturbingFunction`Private`c2_", ",", 
                    "DisturbingFunction`Private`n_Integer"}], "]"}], ":=", 
                    RowBox[{"Module", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    
                    RowBox[{"DisturbingFunction`Private`absarglist", ",", 
                    "DisturbingFunction`Private`arglist", ",", 
                    "DisturbingFunction`Private`degree", ",", 
                    "DisturbingFunction`Private`temparg", ",", 
                    RowBox[{"DisturbingFunction`Private`order", "=", 
                    RowBox[{"Abs", "[", 
                    
                    RowBox[{"DisturbingFunction`Private`c1", "+", 
                    "DisturbingFunction`Private`c2"}], "]"}]}], ",", 
                    
                    RowBox[{"DisturbingFunction`Private`ac1", "=", 
                    "DisturbingFunction`Private`c1"}], ",", 
                    
                    RowBox[{"DisturbingFunction`Private`ac2", "=", 
                    "DisturbingFunction`Private`c2"}], ",", 
                    "DisturbingFunction`Private`ii", ",", 
                    "DisturbingFunction`Private`jj", ",", 
                    "DisturbingFunction`Private`kk", ",", 
                    "DisturbingFunction`Private`ll", ",", 
                    "DisturbingFunction`Private`var"}], "}"}], ",", 
                    RowBox[{
                    RowBox[{"DisturbingFunction`Private`arglist", "=", 
                    RowBox[{"Flatten", "[", 
                    RowBox[{
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    
                    RowBox[{"DisturbingFunction`Private`kk", ",", 
                    "DisturbingFunction`Private`ll", ",", 
                    "DisturbingFunction`Private`ii", ",", 
                    "DisturbingFunction`Private`jj"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"DisturbingFunction`Private`ii", ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`order", "\[Equal]", 
                    "0"}], ",", "0", ",", 
                    RowBox[{"-", "DisturbingFunction`Private`n"}]}], "]"}], 
                    ",", "DisturbingFunction`Private`n"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"DisturbingFunction`Private`jj", ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`order", "\[Equal]", 
                    "0"}], "&&", 
                    
                    RowBox[{"DisturbingFunction`Private`ii", "\[Equal]", 
                    "0"}]}], ",", "0", ",", 
                    RowBox[{
                    RowBox[{"-", "DisturbingFunction`Private`n"}], "+", 
                    
                    RowBox[{"Abs", "[", "DisturbingFunction`Private`ii", 
                    "]"}]}]}], "]"}], ",", 
                    RowBox[{"DisturbingFunction`Private`n", "-", 
                    
                    RowBox[{"Abs", "[", "DisturbingFunction`Private`ii", 
                    "]"}]}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"DisturbingFunction`Private`kk", ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`order", "\[Equal]", 
                    "0"}], "&&", 
                    
                    RowBox[{"DisturbingFunction`Private`ii", "\[Equal]", 
                    "0"}], "&&", 
                    
                    RowBox[{"DisturbingFunction`Private`jj", "\[Equal]", 
                    "0"}]}], ",", "0", ",", 
                    RowBox[{
                    RowBox[{"-", "DisturbingFunction`Private`n"}], "+", 
                    
                    RowBox[{"Abs", "[", "DisturbingFunction`Private`ii", 
                    "]"}], "+", 
                    
                    RowBox[{"Abs", "[", "DisturbingFunction`Private`jj", 
                    "]"}]}]}], "]"}], ",", 
                    RowBox[{"DisturbingFunction`Private`n", "-", 
                    
                    RowBox[{"Abs", "[", "DisturbingFunction`Private`ii", 
                    "]"}], "-", 
                    
                    RowBox[{"Abs", "[", "DisturbingFunction`Private`jj", 
                    "]"}]}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"DisturbingFunction`Private`ll", ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`order", "\[Equal]", 
                    "0"}], "&&", 
                    
                    RowBox[{"DisturbingFunction`Private`ii", "\[Equal]", 
                    "0"}], "&&", 
                    
                    RowBox[{"DisturbingFunction`Private`jj", "\[Equal]", 
                    "0"}], "&&", 
                    
                    RowBox[{"DisturbingFunction`Private`kk", "\[Equal]", 
                    "0"}]}], ",", "0", ",", 
                    RowBox[{
                    RowBox[{"-", "DisturbingFunction`Private`n"}], "+", 
                    
                    RowBox[{"Abs", "[", "DisturbingFunction`Private`ii", 
                    "]"}], "+", 
                    
                    RowBox[{"Abs", "[", "DisturbingFunction`Private`jj", 
                    "]"}], "+", 
                    
                    RowBox[{"Abs", "[", "DisturbingFunction`Private`kk", 
                    "]"}]}]}], "]"}], ",", 
                    RowBox[{"DisturbingFunction`Private`n", "-", 
                    
                    RowBox[{"Abs", "[", "DisturbingFunction`Private`ii", 
                    "]"}], "-", 
                    
                    RowBox[{"Abs", "[", "DisturbingFunction`Private`jj", 
                    "]"}], "-", 
                    
                    RowBox[{"Abs", "[", "DisturbingFunction`Private`kk", 
                    "]"}]}]}], "}"}]}], "]"}], ",", "3"}], "]"}]}], ";", 
                    RowBox[{"DisturbingFunction`Private`arglist", "=", 
                    RowBox[{"Select", "[", 
                    RowBox[{"DisturbingFunction`Private`arglist", ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"DisturbingFunction`Private`order", "+", 
                    RowBox[{"Plus", "@@", "#1"}]}], "\[Equal]", "0"}], 
                    "&"}]}], "]"}]}], ";", 
                    RowBox[{"DisturbingFunction`Private`arglist", "=", 
                    RowBox[{"Select", "[", 
                    RowBox[{"DisturbingFunction`Private`arglist", ",", 
                    RowBox[{
                    RowBox[{"EvenQ", "[", 
                    RowBox[{"Abs", "[", 
                    RowBox[{
                    
                    RowBox[{"#1", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "+", 
                    
                    RowBox[{"#1", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}]}], "]"}], "]"}], "&"}]}], 
                    "]"}]}], ";", 
                    RowBox[{"DisturbingFunction`Private`absarglist", "=", 
                    
                    RowBox[{"Abs", "/@", 
                    "DisturbingFunction`Private`arglist"}]}], ";", 
                    RowBox[{"DisturbingFunction`Private`temparg", "=", 
                    
                    RowBox[{"DisturbingFunction`Private`arglist", "/.", 
                    "\[VeryThinSpace]", 
                    RowBox[{
                    RowBox[{"{", 
                    
                    RowBox[{"DisturbingFunction`Private`x1_", ",", 
                    "DisturbingFunction`Private`x2_", ",", 
                    "DisturbingFunction`Private`x3_", ",", 
                    "DisturbingFunction`Private`x4_"}], "}"}], 
                    "\[RuleDelayed]", 
                    RowBox[{"{", 
                    
                    RowBox[{"DisturbingFunction`Private`x3", ",", 
                    "DisturbingFunction`Private`x4", ",", 
                    "DisturbingFunction`Private`x1", ",", 
                    "DisturbingFunction`Private`x2"}], "}"}]}]}]}], ";", 
                    RowBox[{"DisturbingFunction`Private`degree", "=", 
                    RowBox[{"Apply", "[", 
                    
                    RowBox[{"Plus", ",", 
                    "DisturbingFunction`Private`absarglist", ",", "1"}], 
                    "]"}]}], ";", 
                    RowBox[{"DisturbingFunction`Private`arglist", "=", 
                    RowBox[{"Prepend", "[", 
                    RowBox[{
                    
                    RowBox[{"Transpose", "[", 
                    "DisturbingFunction`Private`arglist", "]"}], ",", 
                    "DisturbingFunction`Private`temparg"}], "]"}]}], ";", 
                    RowBox[{"DisturbingFunction`Private`arglist", "=", 
                    RowBox[{"Prepend", "[", 
                    
                    RowBox[{"DisturbingFunction`Private`arglist", ",", 
                    "DisturbingFunction`Private`absarglist"}], "]"}]}], ";", 
                    RowBox[{"DisturbingFunction`Private`arglist", "=", 
                    RowBox[{"Sort", "[", 
                    RowBox[{"Transpose", "[", 
                    RowBox[{"Prepend", "[", 
                    
                    RowBox[{"DisturbingFunction`Private`arglist", ",", 
                    "DisturbingFunction`Private`degree"}], "]"}], "]"}], 
                    "]"}]}], ";", 
                    RowBox[{"DisturbingFunction`Private`var", "=", 
                    RowBox[{"Variables", "[", 
                    RowBox[{"{", 
                    
                    RowBox[{"DisturbingFunction`Private`c1", ",", 
                    "DisturbingFunction`Private`c2"}], "}"}], "]"}]}], ";", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"DisturbingFunction`Private`var", "=!=", 
                    RowBox[{"{", "}"}]}], ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Coefficient", "[", 
                    RowBox[{"DisturbingFunction`Private`c1", ",", 
                    
                    RowBox[{"DisturbingFunction`Private`var", 
                    "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                    ",", "1"}], "]"}], "\[Equal]", 
                    RowBox[{"-", "1"}]}], ",", 
                    RowBox[{
                    RowBox[{"DisturbingFunction`Private`ac1", "=", 
                    RowBox[{"-", "DisturbingFunction`Private`c1"}]}], ";", 
                    RowBox[{"DisturbingFunction`Private`ac2", "=", 
                    RowBox[{"-", "DisturbingFunction`Private`c2"}]}]}]}], 
                    "]"}], ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"DisturbingFunction`Private`c1", "<", "0"}], ",", 
                    
                    RowBox[{
                    RowBox[{"DisturbingFunction`Private`ac1", "=", 
                    RowBox[{"-", "DisturbingFunction`Private`c1"}]}], ";", 
                    RowBox[{"DisturbingFunction`Private`ac2", "=", 
                    RowBox[{"-", "DisturbingFunction`Private`c2"}]}]}]}], 
                    "]"}]}], "]"}], ";", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    
                    RowBox[{"Length", "[", 
                    "DisturbingFunction`Private`arglist", "]"}], "=!=", "0"}],
                     ",", 
                    RowBox[{
                    RowBox[{"Transpose", "[", 
                    RowBox[{"Drop", "[", 
                    RowBox[{
                    
                    RowBox[{"Transpose", "[", 
                    "DisturbingFunction`Private`arglist", "]"}], ",", "3"}], 
                    "]"}], "]"}], "/.", "\[VeryThinSpace]", 
                    RowBox[{
                    RowBox[{"{", 
                    
                    RowBox[{"DisturbingFunction`Private`x1_", ",", 
                    "DisturbingFunction`Private`x2_", ",", 
                    "DisturbingFunction`Private`x3_", ",", 
                    "DisturbingFunction`Private`x4_"}], "}"}], 
                    "\[RuleDelayed]", 
                    RowBox[{"{", 
                    
                    RowBox[{"DisturbingFunction`Private`ac1", ",", 
                    "DisturbingFunction`Private`ac2", ",", 
                    "DisturbingFunction`Private`x3", ",", 
                    "DisturbingFunction`Private`x4", ",", 
                    "DisturbingFunction`Private`x1", ",", 
                    "DisturbingFunction`Private`x2"}], "}"}]}]}], ",", 
                    "DisturbingFunction`Private`arglist"}], "]"}]}]}], 
                    "]"}]}]}, {" "}}, 
                  GridBoxAlignment -> {"Columns" -> {{Left}}}, 
                  DefaultBaseStyle -> "Column", 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]},
                "RowDefault"]}
             },
             DefaultBaseStyle->"Column",
             GridBoxAlignment->{"Columns" -> {{Left}}},
             
             GridBoxItemSize->{
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
            "Column"],
           FrameMargins->{{6, 0}, {3, 6}}], "\<\"\"\>"},
         {
          PaneBox[GridBox[{
             {
              
              DynamicModuleBox[{System`InformationDump`open$$ = {
               False, False, False, False, False, False}}, 
               StyleBox[GridBox[{
                  {
                   TagBox[
                    TooltipBox[
                    StyleBox["\<\" Attributes\"\>", "InformationRowLabel",
                    StripOnInput->False],
                    "\"Attributes\"",
                    TooltipStyle->"TextStyling"],
                    Annotation[#, "Attributes", "Tooltip"]& ], 
                   RowBox[{"{", "Protected", "}"}]},
                  {
                   TagBox[
                    TooltipBox[
                    StyleBox["\<\" Full Name\"\>", "InformationRowLabel",
                    StripOnInput->False],
                    "\"FullName\"",
                    TooltipStyle->"TextStyling"],
                    
                    Annotation[#, "FullName", 
                    "Tooltip"]& ], "\<\"DisturbingFunction`ValidArguments\"\>"}
                 },
                 AutoDelete->False,
                 GridBoxAlignment->{"Columns" -> {Right, Left}},
                 GridBoxDividers->None,
                 GridBoxItemSize->{"Columns" -> {Automatic, Automatic}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.5599999999999999]}, 
                    Offset[0.27999999999999997`]}, "Rows" -> {
                    Offset[0.2], {
                    Offset[0.8]}, 
                    Offset[0.2]}}], "DialogStyle",
                StripOnInput->False],
               DynamicModuleValues:>{}]}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            GridBoxDividers->{"Columns" -> {{False}}, "Rows" -> {{False}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.5599999999999999]}, 
                Offset[0.27999999999999997`]}, "Rows" -> {
                Offset[0.2], {
                 Offset[3.6]}, 
                Offset[0.2]}}],
           FrameMargins->{{6, 6}, {6, 3}}], ""},
         {
          ItemBox[
           TagBox[
            ButtonBox[
             PaneSelectorBox[{False->
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "UpPointerOpener"]], True->
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "UpPointerOpenerHot"]]}, Dynamic[
              System`InformationDump`mouseOver$$]],
             Alignment->Left,
             Appearance->{"Default" -> None},
             
             ButtonFunction:>FEPrivate`Set[
              System`InformationDump`open$$, False],
             Evaluator->Automatic,
             FrameMargins->{{9, 0}, {0, 0}},
             ImageMargins->0,
             ImageSize->Full,
             Method->"Preemptive"],
            
            EventHandlerTag[{
             "MouseEntered" :> 
              FEPrivate`Set[System`InformationDump`mouseOver$$, True], 
              "MouseExited" :> 
              FEPrivate`Set[System`InformationDump`mouseOver$$, False], 
              Method -> "Preemptive", PassEventsDown -> Automatic, 
              PassEventsUp -> True}]],
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False], "\[SpanFromLeft]"}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          GrayLevel[0.8], 
          Thickness[Tiny]],
        GridBoxAlignment->{"Columns" -> {Left, Right}, "Rows" -> {{Center}}},
        GridBoxDividers->{
         "Columns" -> {{None}}, "Rows" -> {False, {True}, False}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"], False->
      TagBox[GridBox[{
         {
          ItemBox[
           PaneBox[
            StyleBox["\<\" Symbol\"\>", "InformationTitleText",
             StripOnInput->False],
            FrameMargins->{{4, 0}, {-1, 1}}],
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False], 
          ItemBox["\<\"\"\>",
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False]},
         {
          ItemBox[
           PaneBox[
            
            StyleBox["\<\"ValidArguments[c1,c2,pw] produces an ordered list \
of valid arguments of the expansion of the disturbing function up to and \
including degree 'pw' which start with \\!\\(\\*SubscriptBox[\\(c\\), \
\\(1\\)]\\)\[Lambda]'+\\!\\(\\*SubscriptBox[\\(c\\), \\(2\\)]\\)\[Lambda].  \
The components of each argument, {\\!\\(\\*SubscriptBox[\\(c\\), \\(1\\)]\\),\
\\!\\(\\*SubscriptBox[\\(c\\), \\(2\\)]\\),\\!\\(\\*SubscriptBox[\\(c\\), \
\\(3\\)]\\),\\!\\(\\*SubscriptBox[\\(c\\), \\(4\\)]\\),\\!\\(\\*SubscriptBox[\
\\(c\\), \\(5\\)]\\),\\!\\(\\*SubscriptBox[\\(c\\), \\(6\\)]\\)}, represent \
the argument \\!\\(\\*SubscriptBox[\\(c\\), \
\\(1\\)]\\)\[Lambda]'+\\!\\(\\*SubscriptBox[\\(c\\), \\(2\\)]\\)\[Lambda]+\\!\
\\(\\*SubscriptBox[\\(c\\), \\(3\\)]\\)\[CurlyPi]'+\\!\\(\\*SubscriptBox[\\(c\
\\), \\(4\\)]\\)\[CurlyPi]+\\!\\(\\*SubscriptBox[\\(c\\), \\(5\\)]\\)\
\[CapitalOmega]'+\\!\\(\\*SubscriptBox[\\(c\\), \\(6\\)]\\)\[CapitalOmega].  \
c1 and c2 are integers of the form, e.g. j and i-j, where i, the order of the \
resonance, is an integer.\"\>", "InformationUsageText",
             StripOnInput->False,
             LineSpacing->{1.5, 1.5, 3.}],
            FrameMargins->{{10, 10}, {8, 10}}],
           BaseStyle->"InformationUsageSubtitleBackground",
           StripOnInput->False], 
          ItemBox["\<\"\"\>",
           BaseStyle->"InformationUsageSubtitleBackground",
           StripOnInput->False]},
         {
          ItemBox[
           TagBox[
            ButtonBox[
             PaneSelectorBox[{False->
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "DownPointerOpener"],
               ImageSizeCache->{10., {2., 8.}}], True->
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "DownPointerOpenerHot"],
               ImageSizeCache->{10., {2., 8.}}]}, Dynamic[
              System`InformationDump`mouseOver$$]],
             Alignment->Left,
             Appearance->{"Default" -> None},
             
             ButtonFunction:>FEPrivate`Set[
              System`InformationDump`open$$, True],
             Evaluator->Automatic,
             FrameMargins->{{9, 0}, {0, 0}},
             ImageMargins->0,
             ImageSize->Full,
             Method->"Preemptive"],
            
            EventHandlerTag[{
             "MouseEntered" :> 
              FEPrivate`Set[System`InformationDump`mouseOver$$, True], 
              "MouseExited" :> 
              FEPrivate`Set[System`InformationDump`mouseOver$$, False], 
              Method -> "Preemptive", PassEventsDown -> Automatic, 
              PassEventsUp -> True}]],
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False], "\[SpanFromLeft]"}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          GrayLevel[0.8], 
          Thickness[Tiny]],
        GridBoxAlignment->{"Columns" -> {Left, Right}, "Rows" -> {{Center}}},
        GridBoxDividers->{
         "Columns" -> {{None}}, "Rows" -> {False, {True}, False}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]}, Dynamic[System`InformationDump`open$$],
      BaselinePosition->Baseline,
      FrameMargins->0,
      ImageSize->Automatic],
     DynamicModuleValues:>{}],
    BaseStyle->"InformationGridFrame",
    StripOnInput->False], "InformationGridPlain",
   StripOnInput->False],
  InformationData[<|
   "ObjectType" -> "Symbol", "Usage" -> 
    "ValidArguments[c1,c2,pw] produces an ordered list of valid arguments of \
the expansion of the disturbing function up to and including degree 'pw' \
which start with \!\(\*SubscriptBox[\(c\), \
\(1\)]\)\[Lambda]'+\!\(\*SubscriptBox[\(c\), \(2\)]\)\[Lambda].  The \
components of each argument, {\!\(\*SubscriptBox[\(c\), \
\(1\)]\),\!\(\*SubscriptBox[\(c\), \(2\)]\),\!\(\*SubscriptBox[\(c\), \
\(3\)]\),\!\(\*SubscriptBox[\(c\), \(4\)]\),\!\(\*SubscriptBox[\(c\), \
\(5\)]\),\!\(\*SubscriptBox[\(c\), \(6\)]\)}, represent the argument \
\!\(\*SubscriptBox[\(c\), \(1\)]\)\[Lambda]'+\!\(\*SubscriptBox[\(c\), \(2\)]\
\)\[Lambda]+\!\(\*SubscriptBox[\(c\), \(3\)]\)\[CurlyPi]'+\!\(\*SubscriptBox[\
\(c\), \(4\)]\)\[CurlyPi]+\!\(\*SubscriptBox[\(c\), \(5\)]\)\[CapitalOmega]'+\
\!\(\*SubscriptBox[\(c\), \(6\)]\)\[CapitalOmega].  c1 and c2 are integers of \
the form, e.g. j and i-j, where i, the order of the resonance, is an \
integer.", "Documentation" -> None, "OwnValues" -> None, "UpValues" -> None, 
    "DownValues" -> 
    Information`InformationValueForm[
     DownValues, DisturbingFunction`ValidArguments, {
      DisturbingFunction`ValidArguments[
         Pattern[DisturbingFunction`Private`c1, 
          Blank[]], 
         Pattern[DisturbingFunction`Private`c2, 
          Blank[]], 
         Pattern[DisturbingFunction`Private`n, 
          Blank[Integer]]] :> 
       Module[{DisturbingFunction`Private`absarglist, 
          DisturbingFunction`Private`arglist, 
          DisturbingFunction`Private`degree, 
          DisturbingFunction`Private`temparg, 
          DisturbingFunction`Private`order = 
          Abs[DisturbingFunction`Private`c1 + DisturbingFunction`Private`c2], 
          DisturbingFunction`Private`ac1 = DisturbingFunction`Private`c1, 
          DisturbingFunction`Private`ac2 = DisturbingFunction`Private`c2, 
          DisturbingFunction`Private`ii, DisturbingFunction`Private`jj, 
          DisturbingFunction`Private`kk, DisturbingFunction`Private`ll, 
          DisturbingFunction`Private`var}, 
         DisturbingFunction`Private`arglist = Flatten[
            
            Table[{DisturbingFunction`Private`kk, 
              DisturbingFunction`Private`ll, DisturbingFunction`Private`ii, 
              DisturbingFunction`Private`jj}, {
             DisturbingFunction`Private`ii, 
              If[
              DisturbingFunction`Private`order == 0, 0, -
               DisturbingFunction`Private`n], DisturbingFunction`Private`n}, {
             DisturbingFunction`Private`jj, 
              If[
               And[
               DisturbingFunction`Private`order == 0, 
                DisturbingFunction`Private`ii == 0], 
               0, -DisturbingFunction`Private`n + 
               Abs[DisturbingFunction`Private`ii]], 
              DisturbingFunction`Private`n - Abs[
              DisturbingFunction`Private`ii]}, {DisturbingFunction`Private`kk, 
              If[
               And[
               DisturbingFunction`Private`order == 0, 
                DisturbingFunction`Private`ii == 0, 
                DisturbingFunction`Private`jj == 0], 
               0, -DisturbingFunction`Private`n + 
               Abs[DisturbingFunction`Private`ii] + 
               Abs[DisturbingFunction`Private`jj]], 
              DisturbingFunction`Private`n - Abs[
              DisturbingFunction`Private`ii] - Abs[
              DisturbingFunction`Private`jj]}, {DisturbingFunction`Private`ll, 
              If[
               And[
               DisturbingFunction`Private`order == 0, 
                DisturbingFunction`Private`ii == 0, 
                DisturbingFunction`Private`jj == 0, 
                DisturbingFunction`Private`kk == 0], 
               0, -DisturbingFunction`Private`n + 
               Abs[DisturbingFunction`Private`ii] + 
               Abs[DisturbingFunction`Private`jj] + 
               Abs[DisturbingFunction`Private`kk]], 
              DisturbingFunction`Private`n - Abs[
              DisturbingFunction`Private`ii] - Abs[
              DisturbingFunction`Private`jj] - Abs[
              DisturbingFunction`Private`kk]}], 3]; 
         DisturbingFunction`Private`arglist = 
          Select[DisturbingFunction`Private`arglist, 
            DisturbingFunction`Private`order + Apply[Plus, #] == 0& ]; 
         DisturbingFunction`Private`arglist = 
          Select[DisturbingFunction`Private`arglist, EvenQ[
             Abs[Part[#, 1] + Part[#, 2]]]& ]; 
         DisturbingFunction`Private`absarglist = 
          Map[Abs, DisturbingFunction`Private`arglist]; 
         DisturbingFunction`Private`temparg = 
          ReplaceAll[DisturbingFunction`Private`arglist, {
              Pattern[DisturbingFunction`Private`x1, 
               Blank[]], 
              Pattern[DisturbingFunction`Private`x2, 
               Blank[]], 
              Pattern[DisturbingFunction`Private`x3, 
               Blank[]], 
              Pattern[DisturbingFunction`Private`x4, 
               Blank[]]} :> {
             DisturbingFunction`Private`x3, DisturbingFunction`Private`x4, 
              DisturbingFunction`Private`x1, DisturbingFunction`Private`x2}]; 
         DisturbingFunction`Private`degree = 
          Apply[Plus, DisturbingFunction`Private`absarglist, 1]; 
         DisturbingFunction`Private`arglist = Prepend[
            Transpose[DisturbingFunction`Private`arglist], 
            DisturbingFunction`Private`temparg]; 
         DisturbingFunction`Private`arglist = 
          Prepend[DisturbingFunction`Private`arglist, 
            DisturbingFunction`Private`absarglist]; 
         DisturbingFunction`Private`arglist = Sort[
            Transpose[
             Prepend[
             DisturbingFunction`Private`arglist, 
              DisturbingFunction`Private`degree]]]; 
         DisturbingFunction`Private`var = 
          Variables[{
            DisturbingFunction`Private`c1, DisturbingFunction`Private`c2}]; 
         If[DisturbingFunction`Private`var =!= {}, 
           If[Coefficient[DisturbingFunction`Private`c1, 
              Part[DisturbingFunction`Private`var, 1], 1] == -1, 
            DisturbingFunction`Private`ac1 = -DisturbingFunction`Private`c1; 
            DisturbingFunction`Private`ac2 = -DisturbingFunction`Private`c2], 
           
           If[
           DisturbingFunction`Private`c1 < 0, 
            DisturbingFunction`Private`ac1 = -DisturbingFunction`Private`c1; 
            DisturbingFunction`Private`ac2 = -DisturbingFunction`Private`c2]]; 
         If[Length[DisturbingFunction`Private`arglist] =!= 0, 
           ReplaceAll[
            Transpose[
             Drop[
              Transpose[DisturbingFunction`Private`arglist], 3]], {
              Pattern[DisturbingFunction`Private`x1, 
               Blank[]], 
              Pattern[DisturbingFunction`Private`x2, 
               Blank[]], 
              Pattern[DisturbingFunction`Private`x3, 
               Blank[]], 
              Pattern[DisturbingFunction`Private`x4, 
               Blank[]]} :> {
             DisturbingFunction`Private`ac1, DisturbingFunction`Private`ac2, 
              DisturbingFunction`Private`x3, DisturbingFunction`Private`x4, 
              DisturbingFunction`Private`x1, DisturbingFunction`Private`x2}], 
           DisturbingFunction`Private`arglist]]}], "SubValues" -> None, 
    "DefaultValues" -> None, "NValues" -> None, "FormatValues" -> None, 
    "Options" -> None, "Attributes" -> {Protected}, "FullName" -> 
    "DisturbingFunction`ValidArguments"|>, False]]], "Output",
 CellChangeTimes->{3.811324559904766*^9, 3.866437597492347*^9, 
  3.8909742945856657`*^9},
 CellLabel->"Out[3]=",ExpressionUUID->"5ae0f762-e0f5-4f93-9dd2-3607f6494323"]
}, Open  ]],

Cell[TextData[{
 "Use ",
 StyleBox["ValidArguments", "Input"],
 " to find all the resonant arguments (associated with terms up to eleventh \
order in the eccentricities and inclinations) of a form 18\[Lambda]'\[Dash]7\
\[Lambda]+ ... ."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"af810cc0-a0cf-4156-9d54-49a74b9cb601"],

Cell[CellGroupData[{

Cell["args187 = ValidArguments[18,-7,11]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[4]:=",ExpressionUUID->"3c1a6060-cb54-4ee1-bafe-0941a4dff802"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "11"}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "10"}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "9"}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "8"}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "7"}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "6"}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "5"}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "4"}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "8"}], ",", 
     RowBox[{"-", "3"}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "9"}], ",", 
     RowBox[{"-", "2"}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "10"}], ",", 
     RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "11"}], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "9"}], ",", "0", ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "8"}], ",", "0", ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "6"}], ",", "0", ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "5"}], ",", "0", ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "4"}], ",", "0", ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "3"}], ",", "0", ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", "0", ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "8"}], ",", 
     RowBox[{"-", "1"}], ",", "0", ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "9"}], ",", "0", ",", "0", ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "6"}], ",", "0", ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "5"}], ",", "0", ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "4"}], ",", "0", ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "3"}], ",", "0", ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "2"}], ",", "0", ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "1"}], ",", "0", ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "7"}], ",", "0", ",", "0", ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "5"}], ",", "0", ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "4"}], ",", "0", ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "3"}], ",", "0", ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "2"}], ",", "0", ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "1"}], ",", "0", ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "5"}], ",", "0", ",", "0", ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "3"}], ",", "0", ",", 
     RowBox[{"-", "8"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "2"}], ",", "0", ",", 
     RowBox[{"-", "8"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "1"}], ",", "0", ",", 
     RowBox[{"-", "8"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}], ",", "0", ",", "0", ",", 
     RowBox[{"-", "8"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "1"}], ",", "0", ",", 
     RowBox[{"-", "10"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", "0", ",", "0", ",", 
     RowBox[{"-", "10"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "9"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "8"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "8"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "9"}], ",", "0", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "5"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "5"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "5"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "5"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "5"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "5"}], ",", "0", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "5"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "7"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "7"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "7"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}], ",", "0", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "7"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "9"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", "0", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "9"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "9"}], ",", 
     RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "8"}], ",", 
     RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "8"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "9"}], ",", "0", ",", 
     RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "5"}], ",", "0", ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}], ",", "0", ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "8"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", "0", ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "8"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "5"}], ",", "0", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "5"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "5"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "5"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}], ",", "0", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "5"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "7"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", "0", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "7"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "5"}], ",", "0", ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}], ",", "0", ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", "0", ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "5"}], ",", "0", ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}], ",", "0", ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "5"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", "0", ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "5"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "6"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "6"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "6"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "6"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "6"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "5"}], ",", "0", ",", 
     RowBox[{"-", "6"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}], ",", "0", ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", "0", ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}], ",", "0", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", "0", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "8"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "8"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "8"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "3"}], ",", "0", ",", 
     RowBox[{"-", "8"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "8"}], ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", "0", ",", 
     RowBox[{"-", "8"}], ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "9"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", "0", ",", 
     RowBox[{"-", "9"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", "0", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "10"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "1"}], ",", "0", ",", 
     RowBox[{"-", "10"}], ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.811324559968616*^9, 3.8664375975398893`*^9, 
  3.890974294629197*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"3903d648-1200-46fa-82f4-13cbc0b14a44"]
}, Open  ]],

Cell["There are 182 such arguments.", "Text",
 CellFrame->True,
 CellChangeTimes->{3.811324571638176*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"fb09668f-b1b4-4867-8481-b031a67a7a7e"],

Cell[CellGroupData[{

Cell["Length[args187]", "Input",
 CellLabel->"In[5]:=",ExpressionUUID->"8b9c8fb7-a4f0-4fa8-89fb-a66a6a1d2107"],

Cell[BoxData["182"], "Output",
 CellChangeTimes->{3.811324559976514*^9, 3.866437597564948*^9, 
  3.890974294659058*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"04e305e3-381c-45c5-a470-07072b32374f"]
}, Open  ]],

Cell["The one we have chosen (arbitrarily) is the thirty-first.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"0e10bdd1-58f6-4662-b64e-0e1069125a4b"],

Cell[CellGroupData[{

Cell["argument=args187[[31]]", "Input",
 CellLabel->"In[6]:=",ExpressionUUID->"db5f029d-fd25-41e8-9c31-a8ea338a4642"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"18", ",", 
   RowBox[{"-", "7"}], ",", "0", ",", 
   RowBox[{"-", "5"}], ",", "0", ",", 
   RowBox[{"-", "6"}]}], "}"}]], "Output",
 CellChangeTimes->{3.811324560032414*^9, 3.8664375976010017`*^9, 
  3.890974294669346*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"23a03536-15a1-4530-8d99-a9e0d9b3c508"]
}, Open  ]],

Cell[TextData[{
 "Show how the function ",
 StyleBox["DisturbingFunctionE", "Input"],
 " is used."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"76967e46-757c-44be-ae3b-1ce447fa1a44"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "DisturbingFunctionE"}]], "Input",
 CellLabel->"In[7]:=",ExpressionUUID->"80f18dac-0c4e-4a16-920b-ba903f48490f"],

Cell[BoxData[
 InterpretationBox[
  StyleBox[
   FrameBox[
    DynamicModuleBox[{System`InformationDump`open$$ = False, 
     System`InformationDump`mouseOver$$ = False}, 
     PaneSelectorBox[{True->
      TagBox[GridBox[{
         {
          ItemBox[
           PaneBox[
            StyleBox["\<\" Symbol\"\>", "InformationTitleText",
             StripOnInput->False,
             BaseStyle -> None],
            FrameMargins->{{4, 0}, {-1, 1}}],
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False], 
          ItemBox["\<\"\"\>",
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False]},
         {
          ItemBox[
           PaneBox[
            
            StyleBox["\<\"DisturbingFunctionE[argument,pmax] finds the full \
coefficient of the disturbing function (direct and indirect parts) which \
contains the cosine of argument for an external perturber.\"\>", 
             "InformationUsageText",
             StripOnInput->False,
             LineSpacing->{1.5, 1.5, 3.}],
            FrameMargins->{{10, 10}, {8, 10}}],
           BaseStyle->"InformationUsageSubtitleBackground",
           StripOnInput->False], 
          ItemBox["\<\"\"\>",
           BaseStyle->"InformationUsageSubtitleBackground",
           StripOnInput->False]},
         {
          PaneBox[
           TagBox[GridBox[{
              {
               StyleBox[
                TagBox[
                 TooltipBox[
                  StyleBox["\<\" Definitions\"\>", "InformationRowLabel",
                   StripOnInput->False],
                  "\"Definitions\"",
                  TooltipStyle->"TextStyling"],
                 Annotation[#, "Definitions", "Tooltip"]& ], "DialogStyle",
                StripOnInput->False]},
              {
               TemplateBox[{"\"\[ThinSpace]\"", 
                 GridBox[{{
                    RowBox[{
                    RowBox[{"DisturbingFunctionE", "[", 
                    
                    RowBox[{
                    "DisturbingFunction`Private`argument_List", ",", 
                    "DisturbingFunction`Private`pmax_Integer"}], "]"}], ":=", 
                    
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"\[ScriptCapitalG]", " ", 
                    SuperscriptBox[
                    "m", "\[Prime]", MultilineFunction -> None]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"DirectPart", "[", 
                    
                    RowBox[{"DisturbingFunction`Private`argument", ",", 
                    "DisturbingFunction`Private`pmax"}], "]"}], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`argument", 
                    "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                    " ", 
                    SuperscriptBox[
                    "\[Lambda]", "\[Prime]", MultilineFunction -> None]}], 
                    "+", 
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`argument", 
                    "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
                    " ", "\[Lambda]"}], "+", 
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`argument", 
                    "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
                    " ", 
                    SuperscriptBox[
                    "\[CurlyPi]", "\[Prime]", MultilineFunction -> None]}], 
                    "+", 
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`argument", 
                    "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
                    " ", "\[CurlyPi]"}], "+", 
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`argument", 
                    "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}], 
                    " ", 
                    SuperscriptBox[
                    "\[CapitalOmega]", "\[Prime]", MultilineFunction -> 
                    None]}], "+", 
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`argument", 
                    "\[LeftDoubleBracket]", "6", "\[RightDoubleBracket]"}], 
                    " ", "\[CapitalOmega]"}]}], "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"IndirectPartE", "[", 
                    
                    RowBox[{"DisturbingFunction`Private`argument", ",", 
                    "DisturbingFunction`Private`pmax"}], "]"}], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`argument", 
                    "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                    " ", 
                    SuperscriptBox[
                    "\[Lambda]", "\[Prime]", MultilineFunction -> None]}], 
                    "+", 
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`argument", 
                    "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
                    " ", "\[Lambda]"}], "+", 
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`argument", 
                    "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
                    " ", 
                    SuperscriptBox[
                    "\[CurlyPi]", "\[Prime]", MultilineFunction -> None]}], 
                    "+", 
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`argument", 
                    "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
                    " ", "\[CurlyPi]"}], "+", 
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`argument", 
                    "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}], 
                    " ", 
                    SuperscriptBox[
                    "\[CapitalOmega]", "\[Prime]", MultilineFunction -> 
                    None]}], "+", 
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`argument", 
                    "\[LeftDoubleBracket]", "6", "\[RightDoubleBracket]"}], 
                    " ", "\[CapitalOmega]"}]}], "]"}]}]}], ")"}]}], 
                    SuperscriptBox[
                    "a", "\[Prime]", MultilineFunction -> None]]}]}, {" "}}, 
                  GridBoxAlignment -> {"Columns" -> {{Left}}}, 
                  DefaultBaseStyle -> "Column", 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]},
                "RowDefault"]}
             },
             DefaultBaseStyle->"Column",
             GridBoxAlignment->{"Columns" -> {{Left}}},
             
             GridBoxItemSize->{
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
            "Column"],
           FrameMargins->{{6, 0}, {3, 6}}], "\<\"\"\>"},
         {
          PaneBox[GridBox[{
             {
              
              DynamicModuleBox[{System`InformationDump`open$$ = {
               False, False, False, False, False, False}}, 
               StyleBox[GridBox[{
                  {
                   TagBox[
                    TooltipBox[
                    StyleBox["\<\" Attributes\"\>", "InformationRowLabel",
                    StripOnInput->False],
                    "\"Attributes\"",
                    TooltipStyle->"TextStyling"],
                    Annotation[#, "Attributes", "Tooltip"]& ], 
                   RowBox[{"{", "Protected", "}"}]},
                  {
                   TagBox[
                    TooltipBox[
                    StyleBox["\<\" Full Name\"\>", "InformationRowLabel",
                    StripOnInput->False],
                    "\"FullName\"",
                    TooltipStyle->"TextStyling"],
                    
                    Annotation[#, "FullName", 
                    "Tooltip"]& ], \
"\<\"DisturbingFunction`DisturbingFunctionE\"\>"}
                 },
                 AutoDelete->False,
                 GridBoxAlignment->{"Columns" -> {Right, Left}},
                 GridBoxDividers->None,
                 GridBoxItemSize->{"Columns" -> {Automatic, Automatic}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.5599999999999999]}, 
                    Offset[0.27999999999999997`]}, "Rows" -> {
                    Offset[0.2], {
                    Offset[0.8]}, 
                    Offset[0.2]}}], "DialogStyle",
                StripOnInput->False],
               DynamicModuleValues:>{}]}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            GridBoxDividers->{"Columns" -> {{False}}, "Rows" -> {{False}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.5599999999999999]}, 
                Offset[0.27999999999999997`]}, "Rows" -> {
                Offset[0.2], {
                 Offset[3.6]}, 
                Offset[0.2]}}],
           FrameMargins->{{6, 6}, {6, 3}}], ""},
         {
          ItemBox[
           TagBox[
            ButtonBox[
             PaneSelectorBox[{False->
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "UpPointerOpener"]], True->
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "UpPointerOpenerHot"]]}, Dynamic[
              System`InformationDump`mouseOver$$]],
             Alignment->Left,
             Appearance->{"Default" -> None},
             
             ButtonFunction:>FEPrivate`Set[
              System`InformationDump`open$$, False],
             Evaluator->Automatic,
             FrameMargins->{{9, 0}, {0, 0}},
             ImageMargins->0,
             ImageSize->Full,
             Method->"Preemptive"],
            
            EventHandlerTag[{
             "MouseEntered" :> 
              FEPrivate`Set[System`InformationDump`mouseOver$$, True], 
              "MouseExited" :> 
              FEPrivate`Set[System`InformationDump`mouseOver$$, False], 
              Method -> "Preemptive", PassEventsDown -> Automatic, 
              PassEventsUp -> True}]],
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False], "\[SpanFromLeft]"}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          GrayLevel[0.8], 
          Thickness[Tiny]],
        GridBoxAlignment->{"Columns" -> {Left, Right}, "Rows" -> {{Center}}},
        GridBoxDividers->{
         "Columns" -> {{None}}, "Rows" -> {False, {True}, False}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"], False->
      TagBox[GridBox[{
         {
          ItemBox[
           PaneBox[
            StyleBox["\<\" Symbol\"\>", "InformationTitleText",
             StripOnInput->False],
            FrameMargins->{{4, 0}, {-1, 1}}],
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False], 
          ItemBox["\<\"\"\>",
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False]},
         {
          ItemBox[
           PaneBox[
            
            StyleBox["\<\"DisturbingFunctionE[argument,pmax] finds the full \
coefficient of the disturbing function (direct and indirect parts) which \
contains the cosine of argument for an external perturber.\"\>", 
             "InformationUsageText",
             StripOnInput->False,
             LineSpacing->{1.5, 1.5, 3.}],
            FrameMargins->{{10, 10}, {8, 10}}],
           BaseStyle->"InformationUsageSubtitleBackground",
           StripOnInput->False], 
          ItemBox["\<\"\"\>",
           BaseStyle->"InformationUsageSubtitleBackground",
           StripOnInput->False]},
         {
          ItemBox[
           TagBox[
            ButtonBox[
             PaneSelectorBox[{False->
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "DownPointerOpener"],
               ImageSizeCache->{10., {2., 8.}}], True->
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "DownPointerOpenerHot"],
               ImageSizeCache->{10., {2., 8.}}]}, Dynamic[
              System`InformationDump`mouseOver$$]],
             Alignment->Left,
             Appearance->{"Default" -> None},
             
             ButtonFunction:>FEPrivate`Set[
              System`InformationDump`open$$, True],
             Evaluator->Automatic,
             FrameMargins->{{9, 0}, {0, 0}},
             ImageMargins->0,
             ImageSize->Full,
             Method->"Preemptive"],
            
            EventHandlerTag[{
             "MouseEntered" :> 
              FEPrivate`Set[System`InformationDump`mouseOver$$, True], 
              "MouseExited" :> 
              FEPrivate`Set[System`InformationDump`mouseOver$$, False], 
              Method -> "Preemptive", PassEventsDown -> Automatic, 
              PassEventsUp -> True}]],
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False], "\[SpanFromLeft]"}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          GrayLevel[0.8], 
          Thickness[Tiny]],
        GridBoxAlignment->{"Columns" -> {Left, Right}, "Rows" -> {{Center}}},
        GridBoxDividers->{
         "Columns" -> {{None}}, "Rows" -> {False, {True}, False}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]}, Dynamic[System`InformationDump`open$$],
      BaselinePosition->Baseline,
      FrameMargins->0,
      ImageSize->Automatic],
     DynamicModuleValues:>{}],
    BaseStyle->"InformationGridFrame",
    StripOnInput->False], "InformationGridPlain",
   StripOnInput->False],
  InformationData[<|
   "ObjectType" -> "Symbol", "Usage" -> 
    "DisturbingFunctionE[argument,pmax] finds the full coefficient of the \
disturbing function (direct and indirect parts) which contains the cosine of \
argument for an external perturber.", "Documentation" -> None, "OwnValues" -> 
    None, "UpValues" -> None, "DownValues" -> 
    Information`InformationValueForm[
     DownValues, DisturbingFunction`DisturbingFunctionE, {
      DisturbingFunction`DisturbingFunctionE[
         Pattern[DisturbingFunction`Private`argument, 
          Blank[List]], 
         Pattern[DisturbingFunction`Private`pmax, 
          Blank[Integer]]] :> ($CellContext`\[ScriptCapitalG] (
          Derivative[1][$CellContext`m]/Derivative[1][$CellContext`a])) (
         DisturbingFunction`DirectPart[
           DisturbingFunction`Private`argument, 
            DisturbingFunction`Private`pmax] 
          Cos[Part[DisturbingFunction`Private`argument, 1] 
             Derivative[1][$CellContext`\[Lambda]] + 
            Part[DisturbingFunction`Private`argument, 
               2] $CellContext`\[Lambda] + 
            Part[DisturbingFunction`Private`argument, 3] 
             Derivative[1][$CellContext`\[CurlyPi]] + 
            Part[DisturbingFunction`Private`argument, 
               4] $CellContext`\[CurlyPi] + 
            Part[DisturbingFunction`Private`argument, 5] 
             Derivative[1][$CellContext`\[CapitalOmega]] + 
            Part[DisturbingFunction`Private`argument, 
               6] $CellContext`\[CapitalOmega]] + $CellContext`\[Alpha] 
          DisturbingFunction`IndirectPartE[
           DisturbingFunction`Private`argument, 
            DisturbingFunction`Private`pmax] 
          Cos[Part[DisturbingFunction`Private`argument, 1] 
             Derivative[1][$CellContext`\[Lambda]] + 
            Part[DisturbingFunction`Private`argument, 
               2] $CellContext`\[Lambda] + 
            Part[DisturbingFunction`Private`argument, 3] 
             Derivative[1][$CellContext`\[CurlyPi]] + 
            Part[DisturbingFunction`Private`argument, 
               4] $CellContext`\[CurlyPi] + 
            Part[DisturbingFunction`Private`argument, 5] 
             Derivative[1][$CellContext`\[CapitalOmega]] + 
            Part[DisturbingFunction`Private`argument, 
               6] $CellContext`\[CapitalOmega]])}], "SubValues" -> None, 
    "DefaultValues" -> None, "NValues" -> None, "FormatValues" -> None, 
    "Options" -> None, "Attributes" -> {Protected}, "FullName" -> 
    "DisturbingFunction`DisturbingFunctionE"|>, False]]], "Output",
 CellChangeTimes->{3.81132456011117*^9, 3.866437597671843*^9, 
  3.8909742947559767`*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"beb98f59-8cf0-4f6a-93a0-a6c22080d2f5"]
}, Open  ]],

Cell[TextData[{
 "Use ",
 StyleBox["DisturbingFunctionE", "Input"],
 " to find the terms (to eleventh order) associated with this argument."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e18a6ba7-4c1d-4700-b9fa-ce1c880fd719"],

Cell[CellGroupData[{

Cell["resonant = DisturbingFunctionE[argument,11]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[8]:=",ExpressionUUID->"d413792a-7e3a-4d1f-9c4a-3869ad7c46e7"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   SuperscriptBox["a", "\[Prime]",
    MultilineFunction->None]], 
  RowBox[{"\[ScriptCapitalG]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"1577149", " ", 
        SuperscriptBox["e", "5"], " ", 
        SuperscriptBox["s", "6"], " ", 
        SuperscriptBox["\[Alpha]", "3"], " ", 
        RowBox[{"b", "[", 
         RowBox[{
          FractionBox["7", "2"], ",", "15", ",", "0"}], "]"}]}], "4096"]}], 
     "-", 
     FractionBox[
      RowBox[{"1163365", " ", 
       SuperscriptBox["e", "5"], " ", 
       SuperscriptBox["s", "6"], " ", 
       SuperscriptBox["\[Alpha]", "4"], " ", 
       RowBox[{"b", "[", 
        RowBox[{
         FractionBox["7", "2"], ",", "15", ",", "1"}], "]"}]}], "12288"], "-", 
     FractionBox[
      RowBox[{"55475", " ", 
       SuperscriptBox["e", "5"], " ", 
       SuperscriptBox["s", "6"], " ", 
       SuperscriptBox["\[Alpha]", "5"], " ", 
       RowBox[{"b", "[", 
        RowBox[{
         FractionBox["7", "2"], ",", "15", ",", "2"}], "]"}]}], "6144"], "-", 
     
     FractionBox[
      RowBox[{"855", " ", 
       SuperscriptBox["e", "5"], " ", 
       SuperscriptBox["s", "6"], " ", 
       SuperscriptBox["\[Alpha]", "6"], " ", 
       RowBox[{"b", "[", 
        RowBox[{
         FractionBox["7", "2"], ",", "15", ",", "3"}], "]"}]}], "2048"], "-", 
     
     FractionBox[
      RowBox[{"115", " ", 
       SuperscriptBox["e", "5"], " ", 
       SuperscriptBox["s", "6"], " ", 
       SuperscriptBox["\[Alpha]", "7"], " ", 
       RowBox[{"b", "[", 
        RowBox[{
         FractionBox["7", "2"], ",", "15", ",", "4"}], "]"}]}], "12288"], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["e", "5"], " ", 
       SuperscriptBox["s", "6"], " ", 
       SuperscriptBox["\[Alpha]", "8"], " ", 
       RowBox[{"b", "[", 
        RowBox[{
         FractionBox["7", "2"], ",", "15", ",", "5"}], "]"}]}], "12288"]}], 
    ")"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"7", " ", "\[Lambda]"}], "+", 
     RowBox[{"5", " ", "\[CurlyPi]"}], "+", 
     RowBox[{"6", " ", "\[CapitalOmega]"}], "-", 
     RowBox[{"18", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox["m", "\[Prime]",
    MultilineFunction->None]}]}]], "Output",
 CellChangeTimes->{3.811324560169351*^9, 3.866437597713901*^9, 
  3.890974294797236*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"573b1b4e-e30a-41a9-8d04-69749b0b4ed1"]
}, Open  ]],

Cell["\<\
Isolate the dimensionless terms in which we are interested (see Eq.(6.217)).\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"97b04bfd-8158-49be-9dc1-c38e64d7c1d4"],

Cell["Expand[resonant*12288/\[ScriptCapitalG]/m'*a']", "Input",
 CellLabel->"In[9]:=",ExpressionUUID->"d362eba9-2a86-4628-b780-53aa29c6154e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "4731447"}], " ", 
   SuperscriptBox["e", "5"], " ", 
   SuperscriptBox["s", "6"], " ", 
   SuperscriptBox["\[Alpha]", "3"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["7", "2"], ",", "15", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"7", " ", "\[Lambda]"}], "+", 
     RowBox[{"5", " ", "\[CurlyPi]"}], "+", 
     RowBox[{"6", " ", "\[CapitalOmega]"}], "-", 
     RowBox[{"18", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "-", 
  RowBox[{"1163365", " ", 
   SuperscriptBox["e", "5"], " ", 
   SuperscriptBox["s", "6"], " ", 
   SuperscriptBox["\[Alpha]", "4"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["7", "2"], ",", "15", ",", "1"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"7", " ", "\[Lambda]"}], "+", 
     RowBox[{"5", " ", "\[CurlyPi]"}], "+", 
     RowBox[{"6", " ", "\[CapitalOmega]"}], "-", 
     RowBox[{"18", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "-", 
  RowBox[{"110950", " ", 
   SuperscriptBox["e", "5"], " ", 
   SuperscriptBox["s", "6"], " ", 
   SuperscriptBox["\[Alpha]", "5"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["7", "2"], ",", "15", ",", "2"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"7", " ", "\[Lambda]"}], "+", 
     RowBox[{"5", " ", "\[CurlyPi]"}], "+", 
     RowBox[{"6", " ", "\[CapitalOmega]"}], "-", 
     RowBox[{"18", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "-", 
  RowBox[{"5130", " ", 
   SuperscriptBox["e", "5"], " ", 
   SuperscriptBox["s", "6"], " ", 
   SuperscriptBox["\[Alpha]", "6"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["7", "2"], ",", "15", ",", "3"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"7", " ", "\[Lambda]"}], "+", 
     RowBox[{"5", " ", "\[CurlyPi]"}], "+", 
     RowBox[{"6", " ", "\[CapitalOmega]"}], "-", 
     RowBox[{"18", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "-", 
  RowBox[{"115", " ", 
   SuperscriptBox["e", "5"], " ", 
   SuperscriptBox["s", "6"], " ", 
   SuperscriptBox["\[Alpha]", "7"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["7", "2"], ",", "15", ",", "4"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"7", " ", "\[Lambda]"}], "+", 
     RowBox[{"5", " ", "\[CurlyPi]"}], "+", 
     RowBox[{"6", " ", "\[CapitalOmega]"}], "-", 
     RowBox[{"18", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["e", "5"], " ", 
   SuperscriptBox["s", "6"], " ", 
   SuperscriptBox["\[Alpha]", "8"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["7", "2"], ",", "15", ",", "5"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"7", " ", "\[Lambda]"}], "+", 
     RowBox[{"5", " ", "\[CurlyPi]"}], "+", 
     RowBox[{"6", " ", "\[CapitalOmega]"}], "-", 
     RowBox[{"18", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.811324560235464*^9, 3.8664375977362547`*^9, 
  3.890974294827115*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"bf372f1b-b481-4338-b040-61360a5543df"]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1012, 657},
WindowMargins->{{83, Automatic}, {Automatic, 30}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"5374c7b8-6eb6-4594-8913-9d9d1ba5cce9"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 439, 9, 53, "Text",ExpressionUUID->"8b28fb0a-428d-4d6f-b9e7-aec283f9b152"],
Cell[1000, 31, 99, 0, 67, "Section",ExpressionUUID->"ea7d8ce5-727e-496a-b412-fed6b975d708"],
Cell[1102, 33, 532, 12, 141, "Text",ExpressionUUID->"dea4810e-f6e5-4d40-b627-e58c62d9890e"],
Cell[1637, 47, 190, 2, 30, "Input",ExpressionUUID->"ea16910c-c7c9-4eb7-af60-bd4f15c71426"],
Cell[1830, 51, 150, 2, 30, "Input",ExpressionUUID->"47c21d89-83d6-422f-aab9-3951b6f27b83"],
Cell[1983, 55, 215, 7, 53, "Text",ExpressionUUID->"8ffc35f7-1f11-4269-9e2f-d2d134caf1e4"],
Cell[CellGroupData[{
Cell[2223, 66, 135, 2, 30, "Input",ExpressionUUID->"20831f1e-fa37-4bdf-9d54-4e9f0284c6d2"],
Cell[2361, 70, 32454, 691, 143, "Output",ExpressionUUID->"5ae0f762-e0f5-4f93-9dd2-3607f6494323"]
}, Open  ]],
Cell[34830, 764, 358, 9, 76, "Text",ExpressionUUID->"af810cc0-a0cf-4156-9d54-49a74b9cb601"],
Cell[CellGroupData[{
Cell[35213, 777, 161, 2, 30, "Input",ExpressionUUID->"3c1a6060-cb54-4ee1-bafe-0941a4dff802"],
Cell[35377, 781, 34264, 1123, 959, "Output",ExpressionUUID->"3903d648-1200-46fa-82f4-13cbc0b14a44"]
}, Open  ]],
Cell[69656, 1907, 197, 4, 53, "Text",ExpressionUUID->"fb09668f-b1b4-4867-8481-b031a67a7a7e"],
Cell[CellGroupData[{
Cell[69878, 1915, 110, 1, 30, "Input",ExpressionUUID->"8b9c8fb7-a4f0-4fa8-89fb-a66a6a1d2107"],
Cell[69991, 1918, 197, 3, 34, "Output",ExpressionUUID->"04e305e3-381c-45c5-a470-07072b32374f"]
}, Open  ]],
Cell[70203, 1924, 183, 3, 53, "Text",ExpressionUUID->"0e10bdd1-58f6-4662-b64e-0e1069125a4b"],
Cell[CellGroupData[{
Cell[70411, 1931, 117, 1, 30, "Input",ExpressionUUID->"db5f029d-fd25-41e8-9c31-a8ea338a4642"],
Cell[70531, 1934, 340, 8, 34, "Output",ExpressionUUID->"23a03536-15a1-4530-8d99-a9e0d9b3c508"]
}, Open  ]],
Cell[70886, 1945, 220, 7, 53, "Text",ExpressionUUID->"76967e46-757c-44be-ae3b-1ce447fa1a44"],
Cell[CellGroupData[{
Cell[71131, 1956, 140, 2, 30, "Input",ExpressionUUID->"80f18dac-0c4e-4a16-920b-ba903f48490f"],
Cell[71274, 1960, 17344, 402, 119, "Output",ExpressionUUID->"beb98f59-8cf0-4f6a-93a0-a6c22080d2f5"]
}, Open  ]],
Cell[88633, 2365, 262, 7, 53, "Text",ExpressionUUID->"e18a6ba7-4c1d-4700-b9fa-ce1c880fd719"],
Cell[CellGroupData[{
Cell[88920, 2376, 170, 2, 30, "Input",ExpressionUUID->"d413792a-7e3a-4d1f-9c4a-3869ad7c46e7"],
Cell[89093, 2380, 2529, 73, 134, "Output",ExpressionUUID->"573b1b4e-e30a-41a9-8d04-69749b0b4ed1"]
}, Open  ]],
Cell[91637, 2456, 210, 5, 53, "Text",ExpressionUUID->"97b04bfd-8158-49be-9dc1-c38e64d7c1d4"],
Cell[91850, 2463, 141, 1, 30, "Input",ExpressionUUID->"d362eba9-2a86-4628-b780-53aa29c6154e"],
Cell[91994, 2466, 3416, 95, 125, "Output",ExpressionUUID->"bf372f1b-b481-4338-b040-61360a5543df"]
}
]
*)

